<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nb">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Program_Name</source>
        <translation>Program_navn</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="29"/>
        <source>Usage</source>
        <translation>Bruk</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="106"/>
        <source>Dock Preview</source>
        <translation>Forhåndsvisning av samlevinduet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="118"/>
        <source>Add New Application</source>
        <translation>Legg til nytt program</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="131"/>
        <source>Command</source>
        <translation>Kommando</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="301"/>
        <source>Add application</source>
        <translation>Legg til program</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="395"/>
        <source>Delete this application</source>
        <translation>Slett dette programmet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="124"/>
        <source>Border</source>
        <translation>Kant</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="154"/>
        <source>Size</source>
        <translation>Str</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="161"/>
        <source>Background</source>
        <translation>Bakgrunn</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="381"/>
        <source>Back</source>
        <translation>Tilbake</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="184"/>
        <source>File</source>
        <translation>Fil</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="216"/>
        <location filename="../mainwindow.cpp" line="680"/>
        <location filename="../mainwindow.cpp" line="788"/>
        <location filename="../mainwindow.cpp" line="816"/>
        <source>Select icon...</source>
        <translation>Velg ikon …</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="229"/>
        <location filename="../mainwindow.cpp" line="89"/>
        <location filename="../mainwindow.cpp" line="646"/>
        <location filename="../mainwindow.cpp" line="684"/>
        <location filename="../mainwindow.cpp" line="791"/>
        <source>Select...</source>
        <translation>Velg …</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="315"/>
        <source>Move right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="329"/>
        <source>Move left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="441"/>
        <source>Display help </source>
        <translation>Vis hjelp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="444"/>
        <source>Help</source>
        <translation>Hjelp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="451"/>
        <source>Alt+H</source>
        <translation>Alt + H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="480"/>
        <source>About this application</source>
        <translation>Om dette programmet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="483"/>
        <source>About...</source>
        <translation>Om …</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="490"/>
        <source>Alt+B</source>
        <translation>Alt + B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="522"/>
        <source>Quit application</source>
        <translation>Avslutt programmet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="525"/>
        <source>Close</source>
        <translation>Lukk</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="532"/>
        <source>Alt+N</source>
        <translation>Alt + N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="573"/>
        <source>Save</source>
        <translation>Lagre</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="580"/>
        <source>Alt+S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="110"/>
        <source>1. Add applications to the dock one at a time
2. Select a .desktop file or enter a command for the application you want
3. Select icon attributes for size, background (black is standard) and border
4. Press &quot;Add application&quot; to continue or &quot;Save&quot; to finish</source>
        <translation>1. Legg til ett og ett program til samlevinduet
2. Velg en .desktop-fil eller skriv inn kommandoen som starter ønsket program
3. Velg ikonattributter slik som størrelse, bakgrunn (svart er standard) og kant
4. Velg «Legg til program» for å fortsette eller «Lagre» for å avslutte</translation>
    </message>
    <message>
        <source>black</source>
        <translation type="vanished">svart</translation>
    </message>
    <message>
        <source>white</source>
        <translation type="vanished">hvit</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="155"/>
        <source>This tool allows you to create a new dock with one or more applications. You can also edit or delete a dock created earlier.</source>
        <translation>Dette verktøyet kan opprette et nytt samlevindu med ett eller flere programmer. Det kan også redigere eller slette et tidligere opprettet samlevindu.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="157"/>
        <source>Operation mode</source>
        <translation>Handlingsmodus</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="158"/>
        <source>&amp;Close</source>
        <translation>&amp;Lukk</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="159"/>
        <source>&amp;Move</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="160"/>
        <location filename="../mainwindow.cpp" line="328"/>
        <source>&amp;Delete</source>
        <translation>&amp;Slett</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="161"/>
        <source>&amp;Edit</source>
        <translation>&amp;Rediger</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="162"/>
        <source>C&amp;reate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="267"/>
        <source>Dock name</source>
        <translation>Samlevinduets navn</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="268"/>
        <source>Enter the name to show in the Menu:</source>
        <translation>Angi navnet som skal vises i menyen:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="326"/>
        <source>Select dock to delete</source>
        <translation>Velg samlevindu som skal slettes</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="327"/>
        <source>Confirmation</source>
        <translation>Bekreft</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="328"/>
        <source>Are you sure you want to delete %1?</source>
        <translation>Vil du virkelig slette %1?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="328"/>
        <source>&amp;Cancel</source>
        <translation>Avbr&amp;yt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="355"/>
        <source>Next</source>
        <translation>Neste</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="353"/>
        <source>Select dock to move</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="326"/>
        <location filename="../mainwindow.cpp" line="353"/>
        <location filename="../mainwindow.cpp" line="501"/>
        <location filename="../mainwindow.cpp" line="738"/>
        <source>Dock Files (*.mxdk);;All Files (*.*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="363"/>
        <location filename="../mainwindow.cpp" line="385"/>
        <location filename="../mainwindow.cpp" line="747"/>
        <source>Could not open file</source>
        <translation>Klarte ikke åpne fila</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="500"/>
        <source>Overwrite?</source>
        <translation>Overskriv?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="500"/>
        <source>Do you want to overwrite the dock file?</source>
        <translation>Vil du overskrive oppsettsfila til samlevinduet?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="501"/>
        <source>Save file</source>
        <translation>Lagre fil</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="557"/>
        <source>Dock saved</source>
        <translation>Lagret samlevindu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="557"/>
        <source>The dock has been saved.

To edit the newly created dock please select &apos;Edit an existing dock&apos;.</source>
        <translation>Samlevinduet er lagret.

Velg «Rediger et eksisterende samlevindu» for å redigere samlevinduet.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="576"/>
        <source>About %1</source>
        <translation>Om %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="578"/>
        <source>Version: </source>
        <translation>Versjon:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="579"/>
        <source>Description goes here</source>
        <translation>Dette er beskrivelsen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="581"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Opphavsrett (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="582"/>
        <source>%1 License</source>
        <translation>Lisens for %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="591"/>
        <source>%1 Help</source>
        <translation>Hjelpetekst for %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="719"/>
        <source>Select .desktop file</source>
        <translation>Velg .desktop-fil</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="719"/>
        <source>Desktop Files (*.desktop)</source>
        <translation>Skrivebordsfiler (*.desktop)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="738"/>
        <source>Select a dock file</source>
        <translation>Velg en oppsettsfil for samlevindu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="741"/>
        <source>No file selected</source>
        <translation>Ingen fil valgt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="741"/>
        <source>You haven&apos;t selected any dock file to edit.
Creating a new dock instead.</source>
        <translation>Du har ikke valgt noe samlevindu å redigere.
Oppretter et nytt samlevindu istedenfor.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="747"/>
        <source>Could not open selected file.
Creating a new dock instead.</source>
        <translation>Klarte ikke åpne valgt fil.
Oppretter nytt samlevindu istedenfor.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="755"/>
        <source>1. Edit applications one at a time using the Back and Next buttons
2. Add or delete applications as you like
3. When finished click Save</source>
        <translation>1. Rediger ett program om gangen med knappene «Tilbake» og «Neste»
2. Legg til eller slett programmer som du vil
3. Velg «Lagre» når du er ferdig</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="799"/>
        <source>Select icon</source>
        <translation>Velg ikon</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="799"/>
        <source>Icons (*.png *.jpg *.bmp *.xpm *.svg)</source>
        <translation>Ikoner (*.png *.jpg *.bmp *.xpm *.svg)</translation>
    </message>
</context>
<context>
    <name>PickLocation</name>
    <message>
        <location filename="../picklocation.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialogvindu</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="23"/>
        <source>Dock Location</source>
        <translation>Samlevinduets plassering</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="29"/>
        <source>TopCenter</source>
        <translation>Midtstilt øverst</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="45"/>
        <source>BottomLeft</source>
        <translation>Nederst til venstre</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="61"/>
        <source>BottomCenter</source>
        <translation>Midtstilt nederst </translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="80"/>
        <source>TopLeft</source>
        <translation>Øverst til venstre</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="96"/>
        <source>TopRight</source>
        <translation>Øverst til høyre</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="112"/>
        <source>LeftCenter</source>
        <translation>Midtstilt til venstre</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="128"/>
        <source>RightCenter</source>
        <translation>Midtstilt til høyre</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="144"/>
        <source>BottomRight</source>
        <translation>Nederst til høyre</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="160"/>
        <source>RightTop</source>
        <translation>Over til høyre</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="173"/>
        <source>LeftTop</source>
        <translation>Over til venstre</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="189"/>
        <source>LeftBottom</source>
        <translation>Under til venstre</translation>
    </message>
    <message>
        <location filename="../picklocation.ui" line="205"/>
        <source>RightBottom</source>
        <translation>Under til høyre</translation>
    </message>
    <message>
        <location filename="../picklocation.cpp" line="9"/>
        <source>Select dock location</source>
        <translation>Velg samlevinduets plassering</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../about.cpp" line="32"/>
        <source>License</source>
        <translation>Lisens</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="33"/>
        <location filename="../about.cpp" line="43"/>
        <source>Changelog</source>
        <translation>Endringslogg</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="34"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="51"/>
        <source>&amp;Close</source>
        <translation>&amp;Lukk</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="57"/>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>You must run this program as normal user.</source>
        <translation>Du må kjøre dette programmet som en vanlig bruker.</translation>
    </message>
</context>
</TS>
